#! /bin/sh
#
# Runs all of the tests for the SoC processor test fixture.
#
# Reference the error codes

RESULTS=test_results.txt

PC_RESPONSE="no"

# Echo a message that will display on the PC
echo_pc()
{
        echo
        echo "TESTFIXTURE:$*"
        echo
}

# Send a fail message to standard out for pickup by the test fixture PC tool
fail_out()
{
        echo_pc $(date)
        echo_pc "FINISH:FAIL:$*"
        exit 1
}

# Sends a partial failure message to the standard out for pickup by the test fixture PC tool
partial_fail()
{
        echo_pc "PARTIALFAIL:$*"
}

ask_question()
{
	echo_pc "RESPOND:$*"
	read PC_RESPONSE
}

# This function defines the sens_power2_* file to use; based on bank voltage.
bank_voltage()
{
	partnum=$SOM_MODEL
	echo_pc Detecting Bank Voltage
	case $partnum in
	CAM5CS-PRO-A-RI|CAM5CS-PRO-A-RC|CAM5CS-PRO-D-RI)
		BANK_VOLTAGE_NUM="000623"
		;;
	CAM5CS-PRO-B-RC|CAM5CS-PRO-B-RI|CAM5CS-PRO-C-RC)
		BANK_VOLTAGE_NUM="000658"
		;;
	5CS?-H?-4X?-R?-DC|80-000658*)
		BANK_VOLTAGE_NUM="000658"
		;;
	5CS?-H?-4X?-R?-DA|80-000623*)
		BANK_VOLTAGE_NUM="000623"
		;;
	A10S-??-*-*)
		BANK_VOLTAGE_NUM="000681"
		;;
	*)
		echo_pc "$partnum"
		fail_out "ERR60-1 Invalid SOM model; factory config might not be programmed"
		;;
	esac
	echo_pc BANK_VOLTAGE_NUM=$BANK_VOLTAGE_NUM
}

# This function is just a list of the supported SOMs
validate_som()
{
	partnum=$SOM_MODEL
	echo_pc Detecting SOM Model 
	case $partnum in
	CAM5CS-PRO-A-RI|CAM5CS-PRO-A-RC|CAM5CS-PRO-D-RI)
		echo_pc "Detected $partnum as SOM"
		;;
	CAM5CS-PRO-B-RC|CAM5CS-PRO-B-RI|CAM5CS-PRO-C-RC)
		echo_pc "Detected $partnum as SOM"
		;;
	5CS?-H?-4X?-R?-D?|80-000658*|80-000623*)
		echo_pc "Detected $partnum as SOM"
		;;
	A10S-*-*-*)
		echo_pc "Detected $partnum as SOM"
		;;
	*)
		echo_pc "$partnum"
		fail_out "ERR60-1 Invalid SOM model; factory config might not be programmed"
		;;
	esac
}
