#!/bin/sh

script_dir=$(dirname $0)
source "$script_dir/error_codes.sh"

# locals
TYPE="Ethernet test:"
COUNT=5
SERVER=$1
IFACE=eth0
CHECK_PHRASE=", 0% packet loss"
OUT="/tmp/eth_test_tmp"
OUTSPEED="/tmp/eth_test_speed_tmp"
resultlink="UNKNOWN"
resultspeed="UNKNOWN"
result="UNKNOWN"
summary=""

echo "Testing Ethernet using server: $SERVER"
ifconfig ${IFACE}|grep 'inet addr:'

ping $SERVER -c $COUNT | tee $OUT

grep -q "$CHECK_PHRASE" $OUT

echo "Verifying output"
if grep -q "$CHECK_PHRASE" $OUT; then
	# Check phrase found, no error occurred, pass
	resultlink="PASSED"
else
	# Check phrase not found, error occurred, failure
	resultlink="FAILED"
	partial_fail "ERR90-$3 Error pinging on $2"
fi

echo "Testing Ethernet link speed"
ethtool eth0 | tee $OUTSPEED
if grep -q "Speed: 1000Mb/s" $OUTSPEED; then
	resultspeed="PASSED"
else
	resultspeed="FAILED"
	partial_fail "ERR90-2 Network Test Failed to link at 1Gbps"
fi

if [ "${resultlink}" = "PASSED" ] && [ "${resultspeed}" = "PASSED" ]; then
	result="PASSED"
else
	result="FAILED"
	ifconfig
	route
fi

# Print results to summary
# Print results to summary
summary="Ping: $resultlink Speed: $resultspeed"
printf "%-30s$result: " "$TYPE" | tee -a $RESULTS
echo $summary | tee -a $RESULTS

# Clean up
rm $OUT $OUTSPEED

exit 0