#! /bin/sh

script_dir=$(dirname $0)
source "$script_dir/error_codes.sh"

success=""

function query()
{
	ask_question $1

	if [ "$PC_RESPONSE" = "yes" ] || [ "$PC_RESPONSE" = "" ]
	then
			success="PASS"
	else
			success="FAIL"
	fi
}

function result()
{
	echo $1 | tee -a $2
}

gpio_test=$1

TYPE="GPIO test:"
OUT1=/tmp/gpio_test_out
OUT2=/tmp/tricolor_out

if [ "${gpio_test}" = "yes" ]
then

echo "Testing GPIO 0"
${script_dir}setgpio.sh 0 out 1
${script_dir}setgpio.sh 1 out 0
${script_dir}setgpio.sh 2 out 0
${script_dir}setgpio.sh 3 out 0

query "ASKGPIOLED0"
result "GPIO 0 result: $success" $OUT1

echo "Testing GPIO 1"
${script_dir}setgpio.sh 0 out 0
${script_dir}setgpio.sh 1 out 1
${script_dir}setgpio.sh 2 out 0
${script_dir}setgpio.sh 3 out 0

query "ASKGPIOLED1"
result "GPIO 1 result: $success" $OUT1

echo "Testing GPIO 2"
${script_dir}setgpio.sh 0 out 0
${script_dir}setgpio.sh 1 out 0
${script_dir}setgpio.sh 2 out 1
${script_dir}setgpio.sh 3 out 0

query "ASKGPIOLED2"
result "GPIO 2 result: $success" $OUT1

echo "Testing GPIO 3"
${script_dir}setgpio.sh 0 out 0
${script_dir}setgpio.sh 1 out 0
${script_dir}setgpio.sh 2 out 0
${script_dir}setgpio.sh 3 out 1

query "ASKGPIOLED3"
result "GPIO 3 result: $success" $OUT1

# set them all back to inputs.
${script_dir}setgpio.sh 0 in
${script_dir}setgpio.sh 1 in
${script_dir}setgpio.sh 2 in
${script_dir}setgpio.sh 3 in

fi

echo "Testing Tri-color"
# Blue:
pca9553 set 0 0
pca9553 set 1 1
pca9553 set 2 1

query "ASKTRICOLORBLUE"
result "LED blue result: $success" $OUT2

# Red:
pca9553 set 0 1
pca9553 set 1 0
pca9553 set 2 1

# Production felt the next question was asked too soon so we are artifically slowing things down.. Sad!!
sleep .5

query "ASKTRICOLORRED"
result "LED red result: $success" $OUT2

# Green:
pca9553 set 0 1
pca9553 set 1 1
pca9553 set 2 0

# Production felt the next question was asked too soon so we are artifically slowing things down.. Sad!!
sleep .5

query "ASKTRICOLORGREEN"
result "LED green result: $success" $OUT2

# Off:
pca9553 set 0 1
pca9553 set 1 1
pca9553 set 2 1

if [ "${gpio_test}" = "yes" ]
then

if ( grep -q "FAIL" $OUT1 ); then
	SUMMARY="GPIO: FAILED"
	partial_fail "ERR200-2 GPIO test failed"
else
	SUMMARY="GPIO: PASSED"
fi

fi

if ( grep -q "FAIL" $OUT2 ); then
	SUMMARY="$SUMMARY Tri-Color: FAILED"
	partial_fail "ERR200-1 Tri-color LED test failed"
else
	SUMMARY="$SUMMARY Tri-Color: PASSED"
fi

printf %-30s "$TYPE" | tee -a $RESULTS
echo "$SUMMARY" | tee -a $RESULTS

rm -f $OUT1 $OUT2

