#!/bin/sh

script_dir=$(dirname $0)
source "$script_dir/error_codes.sh"

PWR_GPIOS=$script_dir/power_loopback.txt
SENSOR_GPIOS=$script_dir/sensor_loopback.txt

[ "x" != "x$1" ] && PWR_GPIOS=$1
[ "x" != "x$2" ] && SENSOR_GPIOS=$2

[ -f ${PWR_GPIOS} ] || fail_out ${PWR_GPIOS} not found
[ -f ${SENSOR_GPIOS} ] || fail_out ${SENSOR_GPIOS} not found

modprobe gpio-altera
modprobe gpio-camio
modprobe gpio-dwapb

# locals
TYPE="GPIO test:"
OUT1=/tmp/hsmc1_out
OUT2=/tmp/hsmc2_out
OUT3=/tmp/hsmc3_out
SUMMARY=""

echo "Testing sensor side"
gpiotest $SENSOR_GPIOS 2>&1 | tee -a $OUT1 || fail_out $(cat $OUT1)

if ( grep -q "FAIL" $OUT1 ); then
	SUMMARY="Sensor: FAIL"
else
	SUMMARY="Sensor: PASS"
fi
echo
echo "Testing power side"
gpiotest $PWR_GPIOS 2>&1 | tee -a $OUT2 || fail_out $(cat $OUT2)

if ( grep -q "FAIL" $OUT2 ); then
	SUMMARY="$SUMMARY Power: FAIL"
else
	SUMMARY="$SUMMARY Power: PASS"
fi

printf %-30s "$TYPE" | tee -a $RESULTS
echo "$SUMMARY" | tee -a $RESULTS

# Clean up
rm -f $OUT1 $OUT2 $OUT3

