#! /bin/sh
#
# Runs all of the tests for the SoC processor test fixture.

script_dir=$(dirname $0)
source "$script_dir/error_codes.sh"

usb_test=no
gpio_test=no
fan_test=yes

echo "+-------------------------------------------------------------------------------"
echo "| Programming EEPROM"
echo "+-------------------------------------------------------------------------------"
ebconfig -n "$1" -s "$2" -w
part_num=$(ebconfig | grep "Part" | awk '{print $4}')
serial_num=$(ebconfig | grep "Serial" | awk '{print $4}')
if [ "$part_num" != "$1" ]
then
	partial_fail "ERR60-3 Setting part number: FAILED"
else
	echo_pc "Setting part number: $1"
fi

if [ "$serial_num" != "$2" ]
then
	partial_fail "ERR60-3 Setting serial number: FAILED"
else
	echo_pc "Setting part number: $2"
fi

rm -f $RESULTS
echo "+-------------------------------------------------------------------------------"
echo "| Running Tests"
echo "+-------------------------------------------------------------------------------"

echo
echo "+-------------------------------------------------------------------------------"
echo "| Ethernet Test"
echo "+-------------------------------------------------------------------------------"
echo_pc Starting Ethernet Test
${script_dir}eth_test.sh 192.168.1.1 eth0 1

if [ "${usb_test}" = "yes" ]
then
	echo
	echo "+-------------------------------------------------------------------------------"
	echo "| USB0 Test"
	echo "+-------------------------------------------------------------------------------"
	echo_pc Starting USB Test
	${script_dir}eth_test.sh 10.1.47.1 usb0 2
fi

echo
echo "+-------------------------------------------------------------------------------"
echo "| GPIO/LED"
echo "+-------------------------------------------------------------------------------"
echo_pc Starting Gpio Test
${script_dir}gpio_led_test.sh $gpio_test

text=`grep -i "failed" $RESULTS`

if [ "${fan_test}" = "yes" ]
then
	echo
	echo "+-------------------------------------------------------------------------------"
	echo "| Fan Control"
	echo "+-------------------------------------------------------------------------------"
	echo_pc Starting Fan Control Test
	${script_dir}fan_test.sh fan_params
fi

echo
echo "+-------------------------------------------------------------------------------"
echo "| Tests Complete"
echo "+-------------------------------------------------------------------------------"
echo_pc "Test Summary:"
while IFS= read -r LINE
do
	echo_pc "$LINE"
done < "$RESULTS"

text=$(grep -i "failed" $RESULTS)

echo_pc $(date)
if [ "$text" = "" ]; then
	pca9553 set 0 1
	pca9553 set 1 1
	pca9553 set 2 0
	echo_pc "FINISH:SUCCESS"
else
	pca9553 set 0 1
	pca9553 set 1 0
	pca9553 set 2 1
	echo_pc "FINISH:FAILED"
fi

