#! /bin/sh
#
# Runs all of the tests for the SoC processor test fixture.

if [ "" == "`which pca9553`" ]
then
	export PATH=$PATH:`pwd`
fi

script_dir=$(dirname $0)
source "$script_dir/error_codes.sh"

pca9553 pwm 0 1 .5
pca9553 set 0 2
pca9553 set 1 1
pca9553 set 2 1

if [ "" == "`which factoryconfig`" ]
then
	. ./factoryconfig.sh
	export SOM_MODEL="$(FCpartnum)"
else
	export SOM_MODEL=$(factoryconfig -n)
fi

validate_som

has_usb=y
has_rtc=y
has_qspi=y
has_xceiver=y

# adjust defaults
case $SOM_MODEL in
	# eldim configurations
	CAM5CS-*)
		has_usb=n
		has_rtc=n
		has_qspi=n
		has_xceiver=n
		;;
	# no transceivers on 5CSE's
	5CSE-*)
		has_xceiver=n
		;;
	# all others
	*)
		;;
esac

# force ethernet 1 gbit link right at the start
ethtool -s eth0 speed 1000 duplex full
sleep 2

rm -f $RESULTS
echo "+-------------------------------------------------------------------------------"
echo "| Running Tests"
echo "+-------------------------------------------------------------------------------"

if [ $has_usb != "n" ]
then
echo
echo "+-------------------------------------------------------------------------------"
echo "| USB OTG Device Test"
echo "+-------------------------------------------------------------------------------"
echo_pc Starting USB Test
$script_dir/usb_test.sh
fi

echo
echo "+-------------------------------------------------------------------------------"
echo "| Ethernet Test"
echo "+-------------------------------------------------------------------------------"
echo_pc Starting Ethernet Test
cnt=1
while [ $cnt -lt 30 ]
do
	if $(ethtool eth0 | grep -q "Link detected: yes")
	then
		if $(ifconfig eth0 | grep -q "inet addr:")
		then
			break
		else
			echo "$cnt: No address assigned"
		fi
	else
		echo "$cnt: No Link"
	fi
	cnt=$(($cnt + 1))
	sleep 1
done
PINGHOST=10.0.0.23
grep -qs nameserver /etc/resolv.conf && PINGHOST=$(awk '/^nameserver/ {print $2}' /etc/resolv.conf)
$script_dir/eth_test.sh $PINGHOST eth0 1

if [ $has_qspi != "n" ]
then
echo
echo "+-------------------------------------------------------------------------------"
echo "| NOR FLASH Test"
echo "+-------------------------------------------------------------------------------"
echo_pc Starting NOR Flash Test
$script_dir/nor_test.sh
fi

if [ $has_rtc != "n" ]
then
echo
echo "+-------------------------------------------------------------------------------"
echo "| Clock Test"
echo "+-------------------------------------------------------------------------------"
echo_pc Starting Clock Test
$script_dir/rtc_test.sh
fi

echo
echo "+-------------------------------------------------------------------------------"
echo "| GPIO loopback"
echo "+-------------------------------------------------------------------------------"
echo_pc Starting Gpio Test
$script_dir/gpio_test.sh

echo
echo "+-------------------------------------------------------------------------------"
echo "| Power Supply/I2C"
echo "+-------------------------------------------------------------------------------"
echo_pc Starting Power Supply Test
$script_dir/power_supply.sh

if [ $has_xceiver != "n" ]
then
echo
echo "+-------------------------------------------------------------------------------"
echo "| Transceiver Test"
echo "+-------------------------------------------------------------------------------"
echo_pc Starting Tranceiver Test
$script_dir/transceiver_test.sh
fi

text=$(grep -i "failed" $RESULTS)

if [ "$text" = "" ]; then
	pca9553 set 0 1
	pca9553 set 1 1
	pca9553 set 2 0
else
	pca9553 set 0 1
	pca9553 set 1 0
	pca9553 set 2 1
fi

echo
echo "+-------------------------------------------------------------------------------"
echo "| Tests Complete"
echo "+-------------------------------------------------------------------------------"
echo_pc "Test Summary:"
while IFS= read -r LINE
do
	echo_pc "$LINE"
done < "$RESULTS"

echo_pc $(date)
echo_pc "FINISH:SUCCESS"
