#! /bin/sh
#
# Runs all of the tests for the SoC processor test fixture.

has_usb=y
has_rtc=y
has_qspi=n
has_xceiver=n
has_hwmon=y

script_dir=$(dirname $0)
source "$script_dir/error_codes.sh"

pca9553 pwm 0 1 .5
pca9553 set 0 2
pca9553 set 1 1
pca9553 set 2 1

export SOM_MODEL=""
which factoryconfig >/dev/null 2>&1 && SOM_MODEL=$(factoryconfig -n)
# see http://wanda/svn/mityomap/mityomapl138/trunk/sw/common/config/I2CFactoryConfig.h
# offset of ConfigMagicWord = 0
# offset of ConfigVersion = 4
# offset of MACADDR = 8
# offset of NoUse = 16
# offset of Spare = 20
# offset of SerialNumber = 24
# offset of PartNumber = 28
# model number is 28-60
if [ -z "$SOM_MODEL" ]
then
	source "$script_dir/factoryconfig.sh"
    FCisvalid && SOM_MODEL=$(FCpartnum)
fi
[ -z "$SOM_MODEL" ] && fail_out "Unable to read factory config"
# SOM_MODEL should be A10S-... (i.e. A10S-P8-A5E-RC)
# MAC Address = head /sys/bus/i2c/devices/i2c-0/0-0050/eeprom --bytes=14 | tail --bytes=6|od --width=6 -t x1| cut -c9-|sed '/^$/d'|sed s'/ /:/g'
# EEPROM magic# = head /sys/bus/i2c/devices/i2c-0/0-0050/eeprom --bytes=4|od -t x4|cut -c9-|sed '/^$/d'
# 
# Options (append to model number)
#    – None
# C – Conformal Coating
# X – Pre-production
# CR – Conformal Coating w/RTV
#  
#                         +-- eMMC Flash size (X = none, A=8GB)
#                         |+-- FPGA RAM size  (X = none, 5=2GB)
#                         ||+-- HPS RAM size  (D = 2GB, E=4GB)
#                         |||
#                 A10S-P8-A5E-RC-SB
# 				---- -- --- -- --    Input Voltage
# CPU --------------+  ||     || |+---  A = 5V, B = 12V
#   A10S               ||     || +----  SoM I/O D = Dual sided, S = Single Sided
#                      ||     |+--- Commercial/Industrial
# CPU Speed Grade -----+|     +---- RoHS
#  J – 1.5 GHz, Fabric Speed = 1
#  P – 1.2 GHz, Fabric Speed = 2
#                       |
# FPGA Size ------------+
# Altera
#  7 – 160 KLE’s
#  8 – 270 KLE’s
#  9 – 480 KLE’s
# 
validate_som

rm -f $RESULTS
echo "+-------------------------------------------------------------------------------"
echo "| Running Tests"
echo "+-------------------------------------------------------------------------------"
echo -n FPGA Timestamp: 
date -d @$(memtool ff200000 4|awk '/^0xFF/ {print "ibase=16; "$3}'|bc)

echo
echo "+-------------------------------------------------------------------------------"
echo "| RAM Test (HPS and FPGA RAM)"
echo "+-------------------------------------------------------------------------------"
echo_pc Starting RAM Test
$script_dir/test-fpga-ddr -b 0x40000000 -s 0xc0000000


if [ $has_usb != "n" ]
then
echo
echo "+-------------------------------------------------------------------------------"
echo "| USB OTG Device Test"
echo "+-------------------------------------------------------------------------------"
echo_pc Starting USB Test
$script_dir/usb_test.sh
fi

echo
echo "+-------------------------------------------------------------------------------"
echo "| Ethernet Test"
echo "+-------------------------------------------------------------------------------"
echo_pc Starting Ethernet Test
PINGHOST=10.0.0.23
grep -qs nameserver /etc/resolv.conf && PINGHOST=$(awk '/^nameserver/ {print $2}' /etc/resolv.conf)
$script_dir/eth_test.sh $PINGHOST eth0 1

if [ $has_qspi != "n" ]
then
echo
echo "+-------------------------------------------------------------------------------"
echo "| NOR FLASH Test"
echo "+-------------------------------------------------------------------------------"
echo_pc Starting NOR Flash Test
$script_dir/nor_test.sh
fi

if [ $has_rtc != "n" ]
then
echo
echo "+-------------------------------------------------------------------------------"
echo "| Clock Test"
echo "+-------------------------------------------------------------------------------"
echo_pc Starting Clock Test
$script_dir/rtc_test.sh
fi

if [ $has_hwmon != "n" ]
then
echo
echo "+-------------------------------------------------------------------------------"
echo "| HW Monitor Test"
echo "+-------------------------------------------------------------------------------"
echo_pc Starting HW Monitor Test
$script_dir/hwmon_test.sh
fi


echo
echo "+-------------------------------------------------------------------------------"
echo "| GPIO loopback"
echo "+-------------------------------------------------------------------------------"
echo_pc Starting Gpio Test
PWR_GPIOS=power_loopback.txt
SENSOR_GPIOS=sensor_loopback.txt
#
# Should be more selective here... technically the single sided I/O modules would not
# have the sensor I/O (I think...), but for now just check for A10 module.
#
if echo $SOM_MODEL|grep -qs "^A10S-"
then
PWR_GPIOS=$script_dir/80-000860_loopback.txt
SENSOR_GPIOS=$script_dir/80-000861_loopback.txt
fi
$script_dir/gpio_test.sh $PWR_GPIOS $SENSOR_GPIOS

echo
echo "+-------------------------------------------------------------------------------"
echo "| Power Supply/I2C"
echo "+-------------------------------------------------------------------------------"
echo_pc Starting Power Supply Test
$script_dir/power_supply.sh

if [ $has_xceiver != "n" ]
then
echo
echo "+-------------------------------------------------------------------------------"
echo "| Transceiver Test"
echo "+-------------------------------------------------------------------------------"
echo_pc Starting Tranceiver Test
$script_dir/transceiver_test.sh
fi

text=$(grep -i "fail" $RESULTS)

if [ "$text" = "" ]; then
	pca9553 set 0 1
	pca9553 set 1 1
	pca9553 set 2 0
else
	pca9553 set 0 1
	pca9553 set 1 0
	pca9553 set 2 1
fi

echo
echo "+-------------------------------------------------------------------------------"
echo "| Tests Complete"
echo "+-------------------------------------------------------------------------------"
echo_pc "Test Summary:"
while IFS= read -r LINE
do
	echo_pc "$LINE"
done < "$RESULTS"

echo_pc $(date)
echo_pc "FINISH:SUCCESS"
